@@ -1,9 +1,6 @@
 from .filters import *
-from .filters import __all__ as _all_
+from .filters import __all__
 
 
-__version__ = "0.1.1"
+__version__ = "0.1.5"
 __github__ = "http://github.com/Den4ikSuperOstryyPer4ik/hikka_filters"
-
-
-__all__ = _all_
\ No newline at end of file
